@@ -114,11 +114,6 @@ VisitDirHandle * fr_archive_add_with_wildcard  (FRArchive     *archive,
 						gboolean       update,
 						gboolean       recursive,
 						gboolean       follow_links,
-						/*gboolean       same_fs,
-						gboolean       no_backup_files,
-						gboolean       no_dot_files,
-						gboolean       ignore_case,
-						*/
 						const char    *password,
 						FRCompression  compression,
 						DoneFunc       done_func,
